/**
 * @author doubledream
 * @desc 获取语言文件
 */

import * as globby from 'globby'
import * as fs from 'fs'
import * as path from 'path'
import { getProjectConfig, flatten } from '../utils'

const CONFIG = getProjectConfig()
// 项目对应语言配置文件夹
const LANG_DIR = path.resolve(CONFIG.canaryDir, CONFIG.srcLang)
// 匹配文件
const I18N_GLOB = `${LANG_DIR}/**/*.${CONFIG.isJsProj ? 'js' : 'ts'}`

/**
 * 获取制定文件JSON内容
 */
function getLangData(fileName) {
  if (fs.existsSync(fileName)) {
    return getLangJson(fileName)
  } else {
    return {}
  }
}

/**
 * 获取文件 Json
 */
function getLangJson(fileName) {
  const fileContent = fs.readFileSync(fileName, { encoding: 'utf8' })
  let obj = fileContent.match(/export\s*default\s*({[\s\S]+)?$/)[1]
  obj = obj.replace(/\s*\s*$/, '')
  obj = obj.replace(';', '')
  let jsObj = {}
  try {
    jsObj = eval('(' + obj + ')')
  } catch (err) {
    console.log(obj)
    console.error(err)
  }
  return jsObj
}

/**
 * 获取项目原语言的I18N内容
 * @return 示例：{ 'common.ts': { test: '测试', chinese: '中国' } }
 */
function getI18N() {
  // 项目对应语言配置文件集合
  const paths = globby.sync(I18N_GLOB)
  const langObj = paths.reduce((prev, curr) => {
    const filename = curr
      .split('/')
      .pop()
      .split('.')
      .shift()
    // 排除index文件
    if (filename === 'index') {
      return prev
    }
    // 获取文件内容
    const fileContent = getLangData(curr)
    let jsObj = fileContent
    // 空对象，说明获取失败
    if (Object.keys(jsObj).length === 0) {
      console.log(`\`${curr}\` 解析失败，该文件包含的文案无法自动补全`)
    }

    return {
      ...prev,
      [filename]: jsObj
    }
  }, {})
  return langObj
}

/**
 * 获取项目原语言的配置, 展平
 * @return 示例：{ 'common.test': '测试', 'common.chinese': '中国' }
 */
function getSrcLangObj() {
  return flatten(getI18N())
}

export { getSrcLangObj, getLangData }
